# oidcrp

![CI build](https://github.com/IdentityPython/JWTConnect-Python-OidcRP/workflows/oidcrp/badge.svg)
![pypi](https://img.shields.io/pypi/v/oidcrp.svg)
[![Downloads total](https://pepy.tech/badge/oidcrp)](https://pepy.tech/project/oidcrp)
[![Downloads week](https://pepy.tech/badge/oidcrp/week)](https://pepy.tech/project/oidcrp)
![License](https://img.shields.io/badge/license-Apache%202-blue.svg)
![Documentation Status](https://readthedocs.org/projects/JWTConnect-Python-OidcRP/badge/?version=latest)
![Python version](https://img.shields.io/badge/python-3.7%20%7C%203.8%20%7C%203.9-blue.svg)


High level interface to the OIDC RP library

oidcrp represents the 3rd layer in the JWTConnect stack (cryptojwt, oidcmsg, oidcrp)

See the documentation at http://oidcrp.readthedocs.io/en/latest/ .

See sample RPs in [example/](https://github.com/IdentityPython/JWTConnect-Python-OidcRP/tree/master/example) folder.

![OIDC Certification mark](doc/source/_images/oid-l-certification-mark-l-rgb-150dpi-90mm-300x157.png)
